# Authors

waterdynamics was created by MDAnalysis in 2023.


All contributing authors are listed in this file below.
The repository history at https://github.com/MDAnalysis/waterdynamics
and the CHANGELOG show individual code contributions.

## Chronological list of authors

<!--
The rules for this file:
  * Authors are sorted chronologically, earliest to latest
  * Please format it each entry as "Preferred name <GitHub username>"
  * Your preferred name is whatever you wish to go by --
    it does *not* have to be your legal name!
  * Please start a new section for each new year
  * Don't ever delete anything
-->

**2023**
Jennifer A Clark <@jaclark5>
Lily Wang <@lilyminium>
Ian Kenney <@ianmkenney>

**2022**
Aditi Tripathi <@aditi2906>
Estefania Barreto-Ojeda <@ojeda-e>

**2020**
Rocco Meli <@RMeli>
Irfan Alibay <@IAlibay>
Cédric Bouysset <@cbouy>

**2018**
Jose Borreguero <@jmborr>
Matt Thompson <@mattwthompson>
Philip Loche <@PicoCentauri>
Paul Smith <@p-j-smith>
Mateusz Bieniek <@bieniekmateusz>

**2017**
Utkarsh Bansal <@utkbansal>

**2016**
Jonathan Barnoud <@jbarnoud>

**2015**
Alejandro Bernardin <@alejob>
Oliver Beckstein <@orbeckst>
Carlos Yañez <cyanez@dlab.cl>
Richard Gowers <@richardjgowers>
Max Linke <@kain88-de>
